﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Activities;
using Microsoft.TeamFoundation.Build.Client;
using Microsoft.TeamFoundation.Build.Workflow.Tracking;
using Microsoft.TeamFoundation.Build.Workflow.Activities;

namespace Benday.TeamBuild2010.Activities
{
    [BuildActivity(HostEnvironmentOption.Agent)]
    public sealed class IisDeleteWebApplication : CodeActivity
    {
        private IisUtility m_iisUtilityInstance;
        public IisUtility IisUtilityInstance
        {
            get
            {
                if (m_iisUtilityInstance == null)
                {
                    m_iisUtilityInstance = new IisUtility();
                }

                return m_iisUtilityInstance;
            }
        }

        [RequiredArgument]
        public InArgument<string> SiteName { get; set; }

        [RequiredArgument]
        public InArgument<string> ApplicationName { get; set; }

        private string VerifySiteName(string siteName)
        {
            if (String.IsNullOrEmpty(siteName) == true)
            {
                var sites = IisUtilityInstance.GetSites();

                if (sites == null || sites.Count < 1)
                {
                    throw new InvalidOperationException("Could not determine default site name because IIS does not contain any sites.");
                }
                else
                {
                    return sites[0];
                }
            }
            else
            {
                return siteName;
            }
        }

        protected override void Execute(CodeActivityContext context)
        {
            try
            {
                LogUtility.WriteToLog(context, "IisDeleteWebApplication: Preparing to delete web application.", BuildMessageImportance.Normal);

                string tempSiteName = SiteName.Get(context);
                string tempApplicationName = ApplicationName.Get(context);

                LogUtility.WriteToLog(context, String.Format("IisDeleteWebApplication: Preparing to delete web application.  (Site: {0}, Application: {1})",
                                               tempSiteName,
                                               tempApplicationName), BuildMessageImportance.Low);

                tempSiteName = VerifySiteName(tempSiteName);

                IisUtilityInstance.DeleteApplication(tempSiteName, tempApplicationName);

                LogUtility.WriteToLog(context, String.Format("IisDeleteWebApplication: Deleted web application.  (Site: {0}, Application: {1})",
                                                   tempSiteName,
                                                   tempApplicationName), BuildMessageImportance.High);
            }
            catch(Exception ex)
            {
                LogUtility.WriteToLog(context, String.Format("IisDeleteWebApplication: An exception occurred.  {0}",
                                                   ex.ToString()), BuildMessageImportance.High);
            }
        }   
    }
}
